==> istio-model-v1alpha3-6.6.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchFilterMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterListenerMatchFilterMatchFluentImpl<A extends EnvoyFilterListenerMatchFilterMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterListenerMatchFilterMatchFluent<A>{
  public EnvoyFilterListenerMatchFilterMatchFluentImpl() {
  }
  public EnvoyFilterListenerMatchFilterMatchFluentImpl(EnvoyFilterListenerMatchFilterMatch instance) {
    this.withName(instance.getName()); 
    this.withSubFilter(instance.getSubFilter()); 
  }
  private String name;
  private EnvoyFilterListenerMatchSubFilterMatchBuilder subFilter;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSubFilter instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterListenerMatchSubFilterMatch getSubFilter() {
    return this.subFilter!=null ?this.subFilter.build():null;
  }
  public EnvoyFilterListenerMatchSubFilterMatch buildSubFilter() {
    return this.subFilter!=null ?this.subFilter.build():null;
  }
  public A withSubFilter(EnvoyFilterListenerMatchSubFilterMatch subFilter) {
    _visitables.get("subFilter").remove(this.subFilter);
    if (subFilter!=null){ this.subFilter= new EnvoyFilterListenerMatchSubFilterMatchBuilder(subFilter); _visitables.get("subFilter").add(this.subFilter);} else { this.subFilter = null; _visitables.get("subFilter").remove(this.subFilter); } return (A) this;
  }
  public Boolean hasSubFilter() {
    return this.subFilter != null;
  }
  public A withNewSubFilter(String name) {
    return (A)withSubFilter(new EnvoyFilterListenerMatchSubFilterMatch(name));
  }
  public EnvoyFilterListenerMatchFilterMatchFluent.SubFilterNested<A> withNewSubFilter() {
    return new EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNestedImpl();
  }
  public EnvoyFilterListenerMatchFilterMatchFluent.SubFilterNested<A> withNewSubFilterLike(EnvoyFilterListenerMatchSubFilterMatch item) {
    return new EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNestedImpl(item);
  }
  public EnvoyFilterListenerMatchFilterMatchFluent.SubFilterNested<A> editSubFilter() {
    return withNewSubFilterLike(getSubFilter());
  }
  public EnvoyFilterListenerMatchFilterMatchFluent.SubFilterNested<A> editOrNewSubFilter() {
    return withNewSubFilterLike(getSubFilter() != null ? getSubFilter(): new EnvoyFilterListenerMatchSubFilterMatchBuilder().build());
  }
  public EnvoyFilterListenerMatchFilterMatchFluent.SubFilterNested<A> editOrNewSubFilterLike(EnvoyFilterListenerMatchSubFilterMatch item) {
    return withNewSubFilterLike(getSubFilter() != null ? getSubFilter(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterListenerMatchFilterMatchFluentImpl that = (EnvoyFilterListenerMatchFilterMatchFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (subFilter != null ? !subFilter.equals(that.subFilter) :that.subFilter != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  subFilter,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (subFilter != null) { sb.append("subFilter:"); sb.append(subFilter); }
    sb.append("}");
    return sb.toString();
  }
  class SubFilterNestedImpl<N> extends EnvoyFilterListenerMatchSubFilterMatchFluentImpl<EnvoyFilterListenerMatchFilterMatchFluent.SubFilterNested<N>> implements EnvoyFilterListenerMatchFilterMatchFluent.SubFilterNested<N>,Nested<N>{
    SubFilterNestedImpl(EnvoyFilterListenerMatchSubFilterMatch item) {
      this.builder = new EnvoyFilterListenerMatchSubFilterMatchBuilder(this, item);
    }
    SubFilterNestedImpl() {
      this.builder = new EnvoyFilterListenerMatchSubFilterMatchBuilder(this);
    }
    EnvoyFilterListenerMatchSubFilterMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterListenerMatchFilterMatchFluentImpl.this.withSubFilter(builder.build());
    }
    public N endSubFilter() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchFilterMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterListenerMatchFilterMatchFluentImpl<A extends EnvoyFilterListenerMatchFilterMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterListenerMatchFilterMatchFluent<A>{
  public EnvoyFilterListenerMatchFilterMatchFluentImpl() {
  }
  public EnvoyFilterListenerMatchFilterMatchFluentImpl(EnvoyFilterListenerMatchFilterMatch instance) {
    if (instance != null) {
      this.withName(instance.getName());
      this.withSubFilter(instance.getSubFilter());
    }
  }
  private String name;
  private EnvoyFilterListenerMatchSubFilterMatchBuilder subFilter;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSubFilter instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterListenerMatchSubFilterMatch getSubFilter() {
    return this.subFilter!=null ?this.subFilter.build():null;
  }
  public EnvoyFilterListenerMatchSubFilterMatch buildSubFilter() {
    return this.subFilter!=null ?this.subFilter.build():null;
  }
  public A withSubFilter(EnvoyFilterListenerMatchSubFilterMatch subFilter) {
    _visitables.get("subFilter").remove(this.subFilter);
    if (subFilter!=null){ this.subFilter= new EnvoyFilterListenerMatchSubFilterMatchBuilder(subFilter); _visitables.get("subFilter").add(this.subFilter);} else { this.subFilter = null; _visitables.get("subFilter").remove(this.subFilter); } return (A) this;
  }
  public Boolean hasSubFilter() {
    return this.subFilter != null;
  }
  public A withNewSubFilter(String name) {
    return (A)withSubFilter(new EnvoyFilterListenerMatchSubFilterMatch(name));
  }
  public EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNested<A> withNewSubFilter() {
    return new EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNestedImpl();
  }
  public EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNested<A> withNewSubFilterLike(EnvoyFilterListenerMatchSubFilterMatch item) {
    return new EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNestedImpl(item);
  }
  public EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNested<A> editSubFilter() {
    return withNewSubFilterLike(getSubFilter());
  }
  public EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNested<A> editOrNewSubFilter() {
    return withNewSubFilterLike(getSubFilter() != null ? getSubFilter(): new EnvoyFilterListenerMatchSubFilterMatchBuilder().build());
  }
  public EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNested<A> editOrNewSubFilterLike(EnvoyFilterListenerMatchSubFilterMatch item) {
    return withNewSubFilterLike(getSubFilter() != null ? getSubFilter(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterListenerMatchFilterMatchFluentImpl that = (EnvoyFilterListenerMatchFilterMatchFluentImpl) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(subFilter, that.subFilter)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  subFilter,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (subFilter != null) { sb.append("subFilter:"); sb.append(subFilter); }
    sb.append("}");
    return sb.toString();
  }
  class SubFilterNestedImpl<N> extends EnvoyFilterListenerMatchSubFilterMatchFluentImpl<EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNested<N>> implements EnvoyFilterListenerMatchFilterMatchFluentImpl.SubFilterNested<N>,Nested<N>{
    SubFilterNestedImpl(EnvoyFilterListenerMatchSubFilterMatch item) {
      this.builder = new EnvoyFilterListenerMatchSubFilterMatchBuilder(this, item);
    }
    SubFilterNestedImpl() {
      this.builder = new EnvoyFilterListenerMatchSubFilterMatchBuilder(this);
    }
    EnvoyFilterListenerMatchSubFilterMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterListenerMatchFilterMatchFluentImpl.this.withSubFilter(builder.build());
    }
    public N endSubFilter() {
      return and();
    }
    
  }
  
}
